var data = [];
var datasize=0;
getStatistics();
/*
* Get statistics from DB
* */
function getStatistics(){
  axios.get('/pagespeed/statistics/json')
    .then(function(response){
      datasize = response.data.length;
      data.mobile = [];
      data.avg = [];
      data.desktop = [];
      data.url = [];
      for(var i=0;i<datasize;i++){
          data.mobile.push(response.data[i].mobile*100);
          data.avg.push(response.data[i].avg*100);
          data.desktop.push(response.data[i].desktop*100);
          data.url.push(response.data[i].url);
      }
      if(datasize==0){
        showWarning('There are no records in the DB. Start a Pagespeed measurement first.');
        document.getElementById("urlfilter").style.display = "none";
      }else{
        drawChart();
      }
    })
    .catch(function(error){
      console.log(error);
      showError('Something went wrong during communicating with the DATABASE. ' +
        'Try to refresh the page or try again later... ');
    });
}
/*
* Visualize statistics with chart.
* */
function drawChart(){
  var ctx = document.getElementById('myChart').getContext('2d');
  var labels = data.url;
  var myChart = new Chart(ctx, {
    type: 'bar',
    data: {
      labels: labels,
      datasets: [
        {
          label: "Mobile",
          backgroundColor: "#2BBCD7",
          data: data.mobile,
        }, {
          label: "AVG",
          backgroundColor: "#15CA7B",
          data: data.avg,
        },
        {
          label: "Desktop",
          backgroundColor: "#D39C49",
          data: data.desktop,
        }
      ]
    },
    options: {
      title: {
        display: true,
        text: 'Last ' +datasize+' measured Pagespeed values'
      }
    }
  });
}

function addElement(parentId, elementTag, html) {
  var p = document.getElementById(parentId);
  var newElement = document.createElement(elementTag);
  newElement.innerHTML = html;
  p.appendChild(newElement);
}

function filterTable(){
  var TableContent = [];
  var filter = document.getElementById("urlfilter");
  var url = filter.options[filter.selectedIndex].value;
  var apiDest= '/pagespeed/statistics/json/sorted?url=';

  if(url!=='reset'){
    apiDest += url;
  }

  axios.get(apiDest)
    .then(function(response){
      if(response.data.error){
        showError('Something went wrong during filtering.');
      }else{
        clearTable();
        response.data.forEach(element =>
          TableContent.push(element)
        );
        TableContent.forEach(element =>
          appendRow(element)
        );
      }

    })
    .catch(function(error){
      showError('Something went wrong during communicating with the DATABASE. ' +
                      'Try to refresh the page or try again later... ');
    });
}

function appendRow(e){
  // Get a reference to the table
  let tableRef = document.getElementById("statTable");

  // Insert a row at the end of the table
  let newRow = tableRef.insertRow(-1);

  // Insert a cell in the row at index 0
  let newCell1 = newRow.insertCell(0);
  let newCell2 = newRow.insertCell(1);
  let newCell3 = newRow.insertCell(2);
  let newCell4 = newRow.insertCell(3);
  let newCell5 = newRow.insertCell(4);

  // Append a text node to the cell
  let newText1 = document.createTextNode(e.created_at);
  let newText2 = document.createTextNode(e.url);
  let newText3 = document.createTextNode(e.mobile);
  let newText4 = document.createTextNode(e.desktop);
  let newText5 = document.createTextNode(e.avg);


  newCell1.appendChild(newText1);
  newCell2.appendChild(newText2);
  newCell3.appendChild(newText3);
  newCell4.appendChild(newText4);
  newCell5.appendChild(newText5);

}

function clearTable(){
  var rows = document.getElementById("statTable").rows.length;
  for(var i=1; i<rows;i++){
    document.getElementById("statTable").deleteRow(1);
  }
}

function showError(msg){
  var html =  '<div class="alert alert-danger" role="alert">' +
    msg +
    '</div>';
  addElement("error_msg","div",html);
}

function showWarning(msg){
  var html =  '<div class="alert alert-warning" role="alert">' +
    msg +
    '</div>';
  addElement("error_msg","div",html);
}

function hideError(){
  let errordiv = document.getElementById("error_msg");
  errordiv.removeChild(errordiv.firstChild);
}

