<?php

namespace Drupal\pagespeed_viewer\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\pagespeed_viewer\PagespeedApiService;
use GuzzleHttp\Exception\GuzzleException;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;


class PagespeedViewerController extends ControllerBase {
  /**
   * Used services
   */
  protected $pagespeedApi;
  protected $pagespeedDB;
  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);
    $instance->pagespeedApi = $container->get('pagespeed_api');
    $instance->pagespeedDB = $container->get('pagespeed_db');
    return $instance;
  }
  /**
   * Renders index page
   *
   * @return array
   *   Index page with variables
   */
  public function init() {
      $url = $this->pagespeedApi->getURL();
      return [
        '#theme' => 'pagespeed_viewer',
        '#url' => $url,
        '#categories' => [
          "0" => "Mobile",
          "1" => "Average",
          "2" => "Desktop",
        ]
      ];
  }
  /**
   * Renders pagespeed overview page
   *
   * @return array
   *   Overview page with pagespeed data
   */
  public function getStatistics(){
    $statistics = $this->pagespeedDB->getStatistics();
    $uniqueURLs = $this->pagespeedDB->getUniqueURLs($statistics);
    return [
      '#theme' => 'pagespeed_viewer_statistics',
      '#statistics' => $statistics,
      '#uniqueURLs' => $uniqueURLs,
    ];
  }
  /**
   * Provides JSON of statistic data
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   */
  public function getStatJson(){
    $statistics = $this->pagespeedDB->getLastFiveAddedStatistics();
    return new JsonResponse($statistics,200);
  }
  /**
   * Provides JSON of pagespeed data
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   */
  public function getPagespeedJson(){
    $json = $this->pagespeedApi->getJSON();
    return new JsonResponse([$json],200);
  }
  /**
   * Provides JSON of statistic data filtered by URL
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   */
  public function filterStatisticsByURL(){
     $url = \Drupal::request()->query->get('url');
     if($url!=''){
       $statistics = $this->pagespeedDB->getStatisticsByURL($url);
     }else{
       $statistics = $this->pagespeedDB->getStatistics();
     }
     if(empty($statistics)){
       $statistics['error'] = true;
     }
    return new JsonResponse($statistics,200);
  }

}
