<?php

namespace Drupal\pagespeed_viewer\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use GuzzleHttp\Client;
use GuzzleHttp\Exception\GuzzleException;

class URLConfigForm extends ConfigFormBase {
  /**
   * Define config file
   */
  const CONFIG = 'pagespeed_viewer.urlconfig';
  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'urlconfig_form';
  }
  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::CONFIG,
    ];
  }
  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $config = $this->config(static::CONFIG);

    $form['url'] = [
      '#type' => 'url',
      '#title' => $this->t('URL:'),
      '#description' => $this->t('Type a page URL which you would like to test'),
      '#default_value' => $config->get('url'),
      '#weight' => '0',
    ];
    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Submit'),
    ];

    return $form;
  }
  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    foreach ($form_state->getValues() as $key => $value) {
      // @TODO: Validate fields.
    }
    parent::validateForm($form, $form_state);
  }
  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $url = $form_state->getValue('url');
    try {
      $client = new Client();
      $response = $client->request('GET', $url);
      $this->configFactory->getEditable(static::CONFIG)
        ->set('url', $url)
        ->save();
      parent::submitForm($form, $form_state);
    }catch(GuzzleException $e){
      \Drupal::messenger()->addError('The given URL is not valid');
    }
  }

}
