<?php

namespace Drupal\pagespeed_viewer;

use Drupal\user\Entity\User;

class PageSpeedDBService {
  /**
   * PageSpeedDBService constructor.
   */
  public function __construct() {

  }
  /**
   * Saves the measured pagespeed into the DB.
   *
   * @param $url
   *    URL of the page.
   * @param $desktop
   *    Desktop pagespeed value
   * @param $mobile
   *    Mobile pagespeed value
   * @param $avg
   *    Average pagespeed value
   */
  public function saveStatisitcs($url, $desktop, $mobile, $avg){
    $statistic = \Drupal::entityTypeManager()
      ->getStorage("pagespeed_data")
      ->create([
        'url' => $url,
        'mobile' => $mobile,
        'desktop' => $desktop,
        'avg' => $avg,
      ]);
    $statistic->save();
  }
  /**
   * Provides statistic objects by ids
   *
   * @param $ids
   *   Array of statistic ids
   *
   * @return array
   *   Array of statistic objects
   */
  public function loadEntities($ids){
    return \Drupal::entityTypeManager()->getStorage('pagespeed_data')->loadMultiple($ids);
  }
  /**
   * Converts statistics values to an array
   *
   * @param $id
   *   List of ids of queried statistics
   *
   * @return array
   *   Array of statistic values
   *
   */
  public function getStatisticsArray($ids){
    $entities = $this->loadEntities($ids);
    $statistics = [];
    $id = 0;
    foreach ($entities as $e){
      $statistics[$id]['url'] = $e->url->value;
      $statistics[$id]['mobile'] = $e->mobile->value;
      $statistics[$id]['desktop'] = $e->desktop->value;
      $statistics[$id]['avg'] = $e->avg->value;
      $statistics[$id]['created_at']= $e->created_at->value;
      $id++;
    }
    return $statistics;
  }
  /**
   * Provides URLs of statistics data listed once
   *
   * @param $statistics
   *   Array of statistic data
   *
   * @return array
   *   URLs of statistic data listed only once
   */
  public function getUniqueURLs($statistics){
    $arr = [];
    for ($i =0;$i<sizeof($statistics);$i++){
      $arr[$i] = $statistics[$i]['url'];
    }
    return array_unique($arr);
  }
  /**
   * Queries for every single statistic
   *
   * @return array
   *   Array of statistics
   */
  public function getStatistics(){
    $ids = \Drupal::entityQuery('pagespeed_data')
      ->sort('created_at','DESC')
      ->execute();
    return $this->getStatisticsArray($ids);
  }
  /**
   * Queries for the last 5 most actual statistics
   *
   * @return array
   *   Array of statistics
   */
  public function getLastFiveAddedStatistics(){
    $ids = \Drupal::entityQuery('pagespeed_data')
      ->sort('created_at','DESC')
      ->range(0,5)
      ->execute();
    return $this->getStatisticsArray($ids);
  }
  /**
   * Queries statistics filtered by the URL.
   *
   * @param $url
   *    URL of the page.
   *
   * @return array
   *   Array of statistics
   */
  public function getStatisticsByURL($url){
    $ids = \Drupal::entityQuery('pagespeed_data')
      ->condition('url',$url)
      ->sort('created_at','ASC')
      ->execute();
    return $this->getStatisticsArray($ids);
  }

}
