<?php

namespace Drupal\pagespeed_viewer;

use GuzzleHttp\Client;
use GuzzleHttp\Exception\GuzzleException;

class PagespeedApiService {
  /**
   * Local variables
   */
  private $url;
  private $mobile;
  private $desktop;
  private $avg;
  /**
   * PagespeedApiService constructor.
   */
  public function __construct() {
    $this->url = $this->getURL();
  }
  /**
   * Queries measured pagespeed from the PageSpeed API
   *
   * @param $device
   *   Mobile or desktop
   */
  public function getPagespeed($device){
    $client = new Client();
    $response = $client->request('GET', 'https://www.googleapis.com/pagespeedonline/v5/runPagespeed?url='
                                                .$this->url
                                                .'&strategy='
                                                .$device);
    $responseObj = json_decode($response->getBody(),1);
    $pagespeed = $responseObj['lighthouseResult']['categories']['performance']['score'];
    $url = $responseObj['lighthouseResult']['requestedUrl'];
    if($device == 'mobile'){
        $this->mobile = $pagespeed;
    }else{
        $this->desktop = $pagespeed;
    }
  }
  /**
   * Calculates average pagespeed
   */
  public function getAvg(){
    $sum = $this->mobile + $this->desktop;
    $this->avg = round($sum/2,2);
  }
  /**
   * Provides URL from config
   */
  public function getURL(){
    $config = \Drupal::config('pagespeed_viewer.urlconfig');
    return $config->get('url');
  }
  /**
   * Provides pagespeed values and saves them into DB
   *
   * @return boolean
   *   Returns true if process was successful,
   *           false if an error occurred
   */
  public function savePagespeed(){
    try {
      $this->getPagespeed('desktop');
      $this->getPagespeed('mobile');
      $dbservice = \Drupal::service('pagespeed_db');
      $this->getAvg();
      $dbservice->saveStatisitcs($this->getURL(), $this->desktop,$this->mobile,$this->avg);
      return true;
    } catch (GuzzleException $e) {
        return false;
    }
  }
  /**
   * Converts pagespeed values to an array
   *
   * @return array
   *   Array of pagespeed values
   */
  public function getJSON(){
      if($this->savePagespeed()){
        return [
          'url' => $this->url,
          'desktop' => $this->desktop,
          'mobile' => $this->mobile,
          'avg' => $this->avg,
        ];
      }
    return ['error' => true,];
  }

}
